@@ -8,9 +8,15 @@ import pytest
 import aiohttp
 from aiohttp import http_websocket
 from aiohttp.http import WebSocketError, WSCloseCode, WSMessage, WSMsgType
-from aiohttp.http_websocket import (_WS_DEFLATE_TRAILING, PACK_CLOSE_CODE,
-                                    PACK_LEN1, PACK_LEN2, PACK_LEN3,
-                                    WebSocketReader, _websocket_mask)
+from aiohttp.http_websocket import (
+    _WS_DEFLATE_TRAILING,
+    PACK_CLOSE_CODE,
+    PACK_LEN1,
+    PACK_LEN2,
+    PACK_LEN3,
+    WebSocketReader,
+    _websocket_mask,
+)
 
 
 def build_frame(message, opcode, use_mask=False, noheader=False, is_fin=True,
@@ -73,7 +79,7 @@ def build_close_frame(code=1000, message=b'', noheader=False):
 
 @pytest.fixture()
 def out(loop):
-    return aiohttp.DataQueue(loop=loop)
+    return aiohttp.DataQueue(loop)
 
 
 @pytest.fixture()
@@ -81,7 +87,7 @@ def parser(out):
     return WebSocketReader(out, 4*1024*1024)
 
 
-def test_parse_frame(parser):
+def test_parse_frame(parser) -> None:
     parser.parse_frame(struct.pack('!BB', 0b00000001, 0b00000001))
     res = parser.parse_frame(b'1')
     fin, opcode, payload, compress = res[0]
@@ -89,14 +95,14 @@ def test_parse_frame(parser):
     assert (0, 1, b'1', False) == (fin, opcode, payload, not not compress)
 
 
-def test_parse_frame_length0(parser):
+def test_parse_frame_length0(parser) -> None:
     fin, opcode, payload, compress = parser.parse_frame(
         struct.pack('!BB', 0b00000001, 0b00000000))[0]
 
     assert (0, 1, b'', False) == (fin, opcode, payload, not not compress)
 
 
-def test_parse_frame_length2(parser):
+def test_parse_frame_length2(parser) -> None:
     parser.parse_frame(struct.pack('!BB', 0b00000001, 126))
     parser.parse_frame(struct.pack('!H', 4))
     res = parser.parse_frame(b'1234')
@@ -105,7 +111,7 @@ def test_parse_frame_length2(parser):
     assert (0, 1, b'1234', False) == (fin, opcode, payload, not not compress)
 
 
-def test_parse_frame_length4(parser):
+def test_parse_frame_length4(parser) -> None:
     parser.parse_frame(struct.pack('!BB', 0b00000001, 127))
     parser.parse_frame(struct.pack('!Q', 4))
     fin, opcode, payload, compress = parser.parse_frame(b'1234')[0]
@@ -113,7 +119,7 @@ def test_parse_frame_length4(parser):
     assert (0, 1, b'1234', False) == (fin, opcode, payload, not not compress)
 
 
-def test_parse_frame_mask(parser):
+def test_parse_frame_mask(parser) -> None:
     parser.parse_frame(struct.pack('!BB', 0b00000001, 0b10000001))
     parser.parse_frame(b'0001')
     fin, opcode, payload, compress = parser.parse_frame(b'1')[0]
@@ -121,13 +127,13 @@ def test_parse_frame_mask(parser):
     assert (0, 1, b'\x01', False) == (fin, opcode, payload, not not compress)
 
 
-def test_parse_frame_header_reversed_bits(out, parser):
+def test_parse_frame_header_reversed_bits(out, parser) -> None:
     with pytest.raises(WebSocketError):
         parser.parse_frame(struct.pack('!BB', 0b01100000, 0b00000000))
         raise out.exception()
 
 
-def test_parse_frame_header_control_frame(out, parser):
+def test_parse_frame_header_control_frame(out, parser) -> None:
     with pytest.raises(WebSocketError):
         parser.parse_frame(struct.pack('!BB', 0b00001000, 0b00000000))
         raise out.exception()
@@ -139,13 +145,13 @@ def _test_parse_frame_header_new_data_err(out, parser):
         raise out.exception()
 
 
-def test_parse_frame_header_payload_size(out, parser):
+def test_parse_frame_header_payload_size(out, parser) -> None:
     with pytest.raises(WebSocketError):
         parser.parse_frame(struct.pack('!BB', 0b10001000, 0b01111110))
         raise out.exception()
 
 
-def test_ping_frame(out, parser):
+def test_ping_frame(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [(1, WSMsgType.PING, b'data', False)]
 
@@ -154,7 +160,7 @@ def test_ping_frame(out, parser):
     assert res == ((WSMsgType.PING, b'data', ''), 4)
 
 
-def test_pong_frame(out, parser):
+def test_pong_frame(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [(1, WSMsgType.PONG, b'data', False)]
 
@@ -163,7 +169,7 @@ def test_pong_frame(out, parser):
     assert res == ((WSMsgType.PONG, b'data', ''), 4)
 
 
-def test_close_frame(out, parser):
+def test_close_frame(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [(1, WSMsgType.CLOSE, b'', False)]
 
@@ -172,7 +178,7 @@ def test_close_frame(out, parser):
     assert res == ((WSMsgType.CLOSE, 0, ''), 0)
 
 
-def test_close_frame_info(out, parser):
+def test_close_frame_info(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [(1, WSMsgType.CLOSE, b'0112345', False)]
 
@@ -181,7 +187,7 @@ def test_close_frame_info(out, parser):
     assert res == (WSMessage(WSMsgType.CLOSE, 12337, '12345'), 0)
 
 
-def test_close_frame_invalid(out, parser):
+def test_close_frame_invalid(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [(1, WSMsgType.CLOSE, b'1', False)]
     parser.feed_data(b'')
@@ -190,7 +196,7 @@ def test_close_frame_invalid(out, parser):
     assert out.exception().code == WSCloseCode.PROTOCOL_ERROR
 
 
-def test_close_frame_invalid_2(out, parser):
+def test_close_frame_invalid_2(out, parser) -> None:
     data = build_close_frame(code=1)
 
     with pytest.raises(WebSocketError) as ctx:
@@ -199,7 +205,7 @@ def test_close_frame_invalid_2(out, parser):
     assert ctx.value.code == WSCloseCode.PROTOCOL_ERROR
 
 
-def test_close_frame_unicode_err(parser):
+def test_close_frame_unicode_err(parser) -> None:
     data = build_close_frame(
         code=1000, message=b'\xf4\x90\x80\x80')
 
@@ -209,7 +215,7 @@ def test_close_frame_unicode_err(parser):
     assert ctx.value.code == WSCloseCode.INVALID_TEXT
 
 
-def test_unknown_frame(out, parser):
+def test_unknown_frame(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [(1, WSMsgType.CONTINUATION, b'', False)]
 
@@ -218,14 +224,14 @@ def test_unknown_frame(out, parser):
         raise out.exception()
 
 
-def test_simple_text(out, parser):
+def test_simple_text(out, parser) -> None:
     data = build_frame(b'text', WSMsgType.TEXT)
     parser._feed_data(data)
     res = out._buffer[0]
     assert res == ((WSMsgType.TEXT, 'text', ''), 4)
 
 
-def test_simple_text_unicode_err(parser):
+def test_simple_text_unicode_err(parser) -> None:
     data = build_frame(b'\xf4\x90\x80\x80', WSMsgType.TEXT)
 
     with pytest.raises(WebSocketError) as ctx:
@@ -234,7 +240,7 @@ def test_simple_text_unicode_err(parser):
     assert ctx.value.code == WSCloseCode.INVALID_TEXT
 
 
-def test_simple_binary(out, parser):
+def test_simple_binary(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [(1, WSMsgType.BINARY, b'binary', False)]
 
@@ -243,7 +249,7 @@ def test_simple_binary(out, parser):
     assert res == ((WSMsgType.BINARY, b'binary', ''), 6)
 
 
-def test_fragmentation_header(out, parser):
+def test_fragmentation_header(out, parser) -> None:
     data = build_frame(b'a', WSMsgType.TEXT)
     parser._feed_data(data[:1])
     parser._feed_data(data[1:])
@@ -252,7 +258,7 @@ def test_fragmentation_header(out, parser):
     assert res == (WSMessage(WSMsgType.TEXT, 'a', ''), 1)
 
 
-def test_continuation(out, parser):
+def test_continuation(out, parser) -> None:
     data1 = build_frame(b'line1', WSMsgType.TEXT, is_fin=False)
     parser._feed_data(data1)
 
@@ -263,7 +269,7 @@ def test_continuation(out, parser):
     assert res == (WSMessage(WSMsgType.TEXT, 'line1line2', ''), 10)
 
 
-def test_continuation_with_ping(out, parser):
+def test_continuation_with_ping(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [
         (0, WSMsgType.TEXT, b'line1', False),
@@ -286,7 +292,7 @@ def test_continuation_with_ping(out, parser):
     assert res == (WSMessage(WSMsgType.TEXT, 'line1line2', ''), 10)
 
 
-def test_continuation_err(out, parser):
+def test_continuation_err(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [
         (0, WSMsgType.TEXT, b'line1', False),
@@ -296,7 +302,7 @@ def test_continuation_err(out, parser):
         parser._feed_data(b'')
 
 
-def test_continuation_with_close(out, parser):
+def test_continuation_with_close(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [
         (0, WSMsgType.TEXT, b'line1', False),
@@ -312,7 +318,7 @@ def test_continuation_with_close(out, parser):
     assert res == (WSMessage(WSMsgType.TEXT, 'line1line2', ''), 10)
 
 
-def test_continuation_with_close_unicode_err(out, parser):
+def test_continuation_with_close_unicode_err(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [
         (0, WSMsgType.TEXT, b'line1', False),
@@ -326,7 +332,7 @@ def test_continuation_with_close_unicode_err(out, parser):
     assert ctx.value.code == WSCloseCode.INVALID_TEXT
 
 
-def test_continuation_with_close_bad_code(out, parser):
+def test_continuation_with_close_bad_code(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [
         (0, WSMsgType.TEXT, b'line1', False),
@@ -340,7 +346,7 @@ def test_continuation_with_close_bad_code(out, parser):
     assert ctx.value.code == WSCloseCode.PROTOCOL_ERROR
 
 
-def test_continuation_with_close_bad_payload(out, parser):
+def test_continuation_with_close_bad_payload(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [
         (0, WSMsgType.TEXT, b'line1', False),
@@ -353,7 +359,7 @@ def test_continuation_with_close_bad_payload(out, parser):
     assert ctx.value.code, WSCloseCode.PROTOCOL_ERROR
 
 
-def test_continuation_with_close_empty(out, parser):
+def test_continuation_with_close_empty(out, parser) -> None:
     parser.parse_frame = mock.Mock()
     parser.parse_frame.return_value = [
         (0, WSMsgType.TEXT, b'line1', False),
@@ -374,7 +380,7 @@ websocket_mask_masked = (b'B]^Q\x11DVFH\x12_[_U\x13PPFR\x14W]A\x14\\S@_X'
                          b'\\T\x14SK\x13CTP@[RYV@')
 
 
-def test_websocket_mask_python():
+def test_websocket_mask_python() -> None:
     message = bytearray(websocket_mask_data)
     http_websocket._websocket_mask_python(
         websocket_mask_mask, message)
@@ -383,14 +389,14 @@ def test_websocket_mask_python():
 
 @pytest.mark.skipif(not hasattr(http_websocket, '_websocket_mask_cython'),
                     reason='Requires Cython')
-def test_websocket_mask_cython():
+def test_websocket_mask_cython() -> None:
     message = bytearray(websocket_mask_data)
     http_websocket._websocket_mask_cython(
         websocket_mask_mask, message)
     assert message == websocket_mask_masked
 
 
-def test_websocket_mask_python_empty():
+def test_websocket_mask_python_empty() -> None:
     message = bytearray()
     http_websocket._websocket_mask_python(
         websocket_mask_mask, message)
@@ -399,14 +405,14 @@ def test_websocket_mask_python_empty():
 
 @pytest.mark.skipif(not hasattr(http_websocket, '_websocket_mask_cython'),
                     reason='Requires Cython')
-def test_websocket_mask_cython_empty():
+def test_websocket_mask_cython_empty() -> None:
     message = bytearray()
     http_websocket._websocket_mask_cython(
         websocket_mask_mask, message)
     assert message == bytearray()
 
 
-def test_msgtype_aliases():
+def test_msgtype_aliases() -> None:
     assert aiohttp.WSMsgType.TEXT == aiohttp.WSMsgType.text
     assert aiohttp.WSMsgType.BINARY == aiohttp.WSMsgType.binary
     assert aiohttp.WSMsgType.PING == aiohttp.WSMsgType.ping
@@ -416,7 +422,7 @@ def test_msgtype_aliases():
     assert aiohttp.WSMsgType.ERROR == aiohttp.WSMsgType.error
 
 
-def test_parse_compress_frame_single(parser):
+def test_parse_compress_frame_single(parser) -> None:
     parser.parse_frame(struct.pack('!BB', 0b11000001, 0b00000001))
     res = parser.parse_frame(b'1')
     fin, opcode, payload, compress = res[0]
@@ -424,7 +430,7 @@ def test_parse_compress_frame_single(parser):
     assert (1, 1, b'1', True) == (fin, opcode, payload, not not compress)
 
 
-def test_parse_compress_frame_multi(parser):
+def test_parse_compress_frame_multi(parser) -> None:
     parser.parse_frame(struct.pack('!BB', 0b01000001, 126))
     parser.parse_frame(struct.pack('!H', 4))
     res = parser.parse_frame(b'1234')
@@ -444,7 +450,7 @@ def test_parse_compress_frame_multi(parser):
     assert (1, 1, b'1234', False) == (fin, opcode, payload, not not compress)
 
 
-def test_parse_compress_error_frame(parser):
+def test_parse_compress_error_frame(parser) -> None:
     parser.parse_frame(struct.pack('!BB', 0b01000001, 0b00000001))
     parser.parse_frame(b'1')
 
@@ -455,7 +461,7 @@ def test_parse_compress_error_frame(parser):
     assert ctx.value.code == WSCloseCode.PROTOCOL_ERROR
 
 
-def test_parse_no_compress_frame_single():
+def test_parse_no_compress_frame_single() -> None:
     parser_no_compress = WebSocketReader(out, 0, compress=False)
     with pytest.raises(WebSocketError) as ctx:
         parser_no_compress.parse_frame(struct.pack(
@@ -465,7 +471,7 @@ def test_parse_no_compress_frame_single():
     assert ctx.value.code == WSCloseCode.PROTOCOL_ERROR
 
 
-def test_msg_too_large(out):
+def test_msg_too_large(out) -> None:
     parser = WebSocketReader(out, 256, compress=False)
     data = build_frame(b'text'*256, WSMsgType.TEXT)
     with pytest.raises(WebSocketError) as ctx:
@@ -473,7 +479,7 @@ def test_msg_too_large(out):
     assert ctx.value.code == WSCloseCode.MESSAGE_TOO_BIG
 
 
-def test_msg_too_large_not_fin(out):
+def test_msg_too_large_not_fin(out) -> None:
     parser = WebSocketReader(out, 256, compress=False)
     data = build_frame(b'text'*256, WSMsgType.TEXT, is_fin=False)
     with pytest.raises(WebSocketError) as ctx:
@@ -481,7 +487,7 @@ def test_msg_too_large_not_fin(out):
     assert ctx.value.code == WSCloseCode.MESSAGE_TOO_BIG
 
 
-def test_compressed_msg_too_large(out):
+def test_compressed_msg_too_large(out) -> None:
     parser = WebSocketReader(out, 256, compress=True)
     data = build_frame(b'aaa'*256, WSMsgType.TEXT, compress=True)
     with pytest.raises(WebSocketError) as ctx:
